@@ -1,4 +1,4 @@
-# Copyright 2022 DARWIN EU (C)
+# Copyright 2024 DARWIN EU (C)
 #
 # This file is part of DrugUtilisation
 #
@@ -16,11 +16,14 @@
 
 #' add daily dose information to a drug_exposure table
 #'
+#' `r lifecycle::badge("deprecated")`
+#'
 #' @param drugExposure drugExposure it must contain drug_concept_id, quantity,
 #' drug_exposure_start_date and drug_exposure_end_date as columns
-#' @param cdm A cdm reference
 #' @param ingredientConceptId ingredientConceptId for which to filter the
 #' drugs of interest
+#' @param name Name of the computed table, if NULL a temporary table will be
+#' generated.
 #'
 #' @return same input table
 #' @export
@@ -32,14 +35,26 @@
 #'
 #' cdm <- mockDrugUtilisation()
 #'
-#' cdm[["drug_exposure"]] %>%
-#'   filter(drug_concept_id == 2905077) %>%
+#' cdm[["drug_exposure"]] |>
+#'   filter(drug_concept_id == 2905077) |>
 #'   addDailyDose(ingredientConceptId = 1125315)
 #' }
 #'
 addDailyDose <- function(drugExposure,
-                         cdm = attr(drugExposure, "cdm_reference"),
-                         ingredientConceptId) {
+                         ingredientConceptId,
+                         name = NULL) {
+  lifecycle::deprecate_soft(when = "0.7.0", what = "addDailyDose()")
+  .addDailyDose(
+    drugExposure = drugExposure,
+    ingredientConceptId = ingredientConceptId,
+    name = name
+  )
+}
+
+.addDailyDose <- function(drugExposure,
+                          ingredientConceptId,
+                          name = NULL) {
+  cdm <- omopgenerics::cdmReference(drugExposure)
   # initial checks
   checkInputs(
     drugExposure = drugExposure, ingredientConceptId = ingredientConceptId,
@@ -49,38 +64,39 @@ addDailyDose <- function(drugExposure,
   nm <- uniqueTmpName()
 
   # select only pattern_id and unit
-  dailyDose <- drugExposure %>%
+  dailyDose <- drugExposure |>
     dplyr::select(
       "drug_concept_id", "drug_exposure_start_date", "drug_exposure_end_date",
       "quantity"
-    ) %>%
+    ) |>
     dplyr::distinct() %>%
     dplyr::mutate(days_exposed = !!CDMConnector::datediff(
       start = "drug_exposure_start_date",
       end = "drug_exposure_end_date"
-    ) + 1) %>%
+    ) + 1) |>
     dplyr::inner_join(
       drugStrengthPattern(cdm = cdm, ingredientConceptId = ingredientConceptId),
       by = "drug_concept_id"
-    ) %>%
-    standardUnits() %>%
-    applyFormula() %>%
+    ) |>
+    standardUnits() |>
+    applyFormula() |>
     dplyr::select(
       "drug_concept_id", "drug_exposure_start_date", "drug_exposure_end_date",
       "quantity", "daily_dose", "unit"
-    ) %>%
+    ) |>
     dplyr::compute(temporary = FALSE, overwrite = TRUE, name = nm)
 
   # add the information back to the initial table
-  drugExposure <- drugExposure %>%
+  drugExposure <- drugExposure |>
     dplyr::left_join(
       dailyDose,
       by = c(
         "drug_concept_id", "drug_exposure_start_date", "drug_exposure_end_date",
         "quantity"
       )
-    ) %>%
-    dplyr::compute()
+    )
+
+  drugExposure <- drugExposure |> compute2(name)
 
   cdm <- omopgenerics::dropTable(cdm = cdm, name = nm)
 
@@ -90,8 +106,12 @@ addDailyDose <- function(drugExposure,
 #' Check coverage of daily dose computation in a sample of the cdm for selected
 #' concept sets and ingredient
 #'
-#' @param cdm A cdm reference created using CDMConnector
-#' @param ingredientConceptId Code indicating the ingredient of interest
+#' @param cdm A cdm reference created using CDMConnector.
+#' @param ingredientConceptId Code indicating the ingredient of interest.
+#' @param estimates Estimates to obtain.
+#' @param sampleSize Maximum number of records of an ingredient to estimate dose
+#'  coverage. If an ingredient has more, a random sample equal to `sampleSize`
+#'  will be considered. If NULL, all records will be used.
 #'
 #' @return The function returns information of the coverage of computeDailyDose.R
 #' for the selected ingredients and concept sets
@@ -103,23 +123,30 @@ addDailyDose <- function(drugExposure,
 #'
 #' cdm <- mockDrugUtilisation()
 #'
-#' dailyDoseCoverage(cdm, 1125315)
+#' summariseDoseCoverage(cdm, 1125315)
 #' }
 #'
-dailyDoseCoverage <- function(cdm,
-                              ingredientConceptId) {
+summariseDoseCoverage <- function(cdm,
+                                  ingredientConceptId,
+                                  estimates = c(
+                                    "count_missing", "percentage_missing",
+                                    "mean", "sd", "q25", "median", "q75"
+                                  ),
+                                  sampleSize = NULL) {
   # initial checks
-  checkInputs(cdm = cdm)
+  checkInputs(cdm = cdm, ingredientConceptId = ingredientConceptId)
+  checkmate::assertIntegerish(x = sampleSize, lower = 0, len = 1, null.ok = TRUE, any.missing = FALSE, )
+  checkmate::assertCharacter(estimates)
 
   # get daily dosage
-  dailyDose <- cdm[["drug_exposure"]] %>%
+  dailyDose <- cdm[["drug_exposure"]] |>
     dplyr::inner_join(
-      cdm[["concept_ancestor"]] %>%
-        dplyr::filter(.data$ancestor_concept_id %in% .env$ingredientConceptId) %>%
-        dplyr::select("drug_concept_id" = "descendant_concept_id") %>%
+      cdm[["concept_ancestor"]] |>
+        dplyr::filter(.data$ancestor_concept_id %in% .env$ingredientConceptId) |>
+        dplyr::select("drug_concept_id" = "descendant_concept_id") |>
         dplyr::distinct(),
       by = "drug_concept_id"
-    ) %>%
+    ) |>
     dplyr::select(
       "drug_concept_id", "drug_exposure_start_date", "drug_exposure_end_date",
       "quantity"
@@ -127,31 +154,40 @@ dailyDoseCoverage <- function(cdm,
     dplyr::mutate(days_exposed = !!CDMConnector::datediff(
       start = "drug_exposure_start_date",
       end = "drug_exposure_end_date"
-    ) + 1) %>%
+    ) + 1) |>
     dplyr::left_join(
       drugStrengthPattern(cdm = cdm, ingredientConceptId = ingredientConceptId),
       by = "drug_concept_id"
-    ) %>%
-    standardUnits() %>%
-    applyFormula() %>%
+    ) |>
+    standardUnits() |>
+    applyFormula() |>
     dplyr::select(
       "drug_concept_id", "daily_dose", "unit", "pattern_id",
-      "concept_id" =  "ingredient_concept_id"
-    ) %>%
-    addRoute() %>%
+      "concept_id" = "ingredient_concept_id"
+    ) |>
+    .addRoute() |>
     dplyr::left_join(
-      cdm[["concept"]] %>%
-        dplyr::rename("ingredient_name" = "concept_name") %>%
+      cdm[["concept"]] |>
+        dplyr::rename("ingredient_name" = "concept_name") |>
         dplyr::select("concept_id", "ingredient_name"),
       by = "concept_id"
-    ) %>%
+    ) |>
     dplyr::collect()
 
+  if (!is.null(sampleSize)) {
+    dailyDose <- dailyDose |>
+      dplyr::group_by(.data$ingredient_name) |>
+      dplyr::sample_n(size = sampleSize, replace = FALSE) |>
+      dplyr::ungroup()
+  } else {
+    sampleSize <- as.integer(NA)
+  }
+
   # summarise
-  dailyDoseSummary <- dailyDose %>%
+  dailyDoseSummary <- dailyDose |>
     dplyr::mutate(dplyr::across(
       c("route", "unit", "pattern_id", "ingredient_name"),
-      ~ dplyr::if_else(is.na(.x), "NA", as.character(.x))
+      ~ dplyr::if_else(is.na(.x), "missing", as.character(.x))
     )) |>
     PatientProfiles::summariseResult(
       group = list("ingredient_name"),
@@ -159,30 +195,61 @@ dailyDoseCoverage <- function(cdm,
       strata = list("unit", c("route", "unit"), c("unit", "route", "pattern_id")),
       includeOverallStrata = TRUE,
       variables = "daily_dose",
-      estimates = c(
-        "count_missing", "percentage_missing", "mean", "sd", "min", "q05",
-        "q25", "median", "q75", "q95", "max"
-      )
-    ) %>%
+      estimates = estimates
+    ) |>
     dplyr::filter(
       !(.data$strata_name %in% c("Overall", "route")) |
         .data$variable_name != "daily_dose" |
         .data$estimate_name %in% c("count", "percentage")
     ) |>
-    dplyr::mutate("cdm_name" = omopgenerics::cdmName(cdm))
+    dplyr::mutate(
+      "cdm_name" = omopgenerics::cdmName(cdm),
+      variable_name = dplyr::if_else(
+        grepl("missing", .data$estimate_name), "Missing dose", .data$variable_name
+      )
+    )
   dailyDoseSummary <- dailyDoseSummary |>
     omopgenerics::newSummarisedResult(settings = dplyr::tibble(
       "result_id" = unique(dailyDoseSummary$result_id),
       "package_name" = "DrugUtilisation",
       "package_version" = as.character(utils::packageVersion("DrugUtilisation")),
-      "result_type" = "dose_coverage"
+      "result_type" = "summarise_dose_coverage",
+      "sample_size" = sampleSize
     ))
 
   return(dailyDoseSummary)
 }
 
+#' Check coverage of daily dose computation in a sample of the cdm for selected
+#' concept sets and ingredient
+#'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' @param cdm A cdm reference created using CDMConnector
+#' @param ingredientConceptId Code indicating the ingredient of interest
+#'
+#' @return The function returns information of the coverage of computeDailyDose.R
+#' for the selected ingredients and concept sets
+#' @export
+#'
+dailyDoseCoverage <- function(cdm,
+                              ingredientConceptId) {
+  lifecycle::deprecate_warn(
+    when = "0.7.0",
+    what = "dailyDoseCoverage()",
+    with = "summariseDoseCoverage()")
+  summariseDoseCoverage(
+    cdm = cdm,
+    ingredientConceptId = ingredientConceptId,
+    estimates = c(
+      "count_missing", "percentage_missing", "mean", "sd", "min", "q05",
+      "q25", "median", "q75", "q95", "max"
+    )
+  )
+}
+
 standardUnits <- function(drugExposure) {
-  drugExposure %>%
+  drugExposure |>
     dplyr::mutate(
       amount_value = dplyr::if_else(
         .data$amount_unit_concept_id == 9655,
@@ -203,7 +270,7 @@ standardUnits <- function(drugExposure) {
     )
 }
 applyFormula <- function(drugExposure) {
-  drugExposure %>%
+  drugExposure |>
     dplyr::mutate(
       daily_dose = dplyr::case_when(
         is.na(.data$quantity) ~
