@@ -1,4 +1,4 @@
-# Copyright 2022 DARWIN EU (C)
+# Copyright 2024 DARWIN EU (C)
 #
 # This file is part of DrugUtilisation
 #
@@ -14,10 +14,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-#' Generates a cohort of the drug use of ingredient name(s) of interest.
+#' Generate a set of drug cohorts based on drug ingredients
 #'
-#' @param cdm A cdm_reference object.
-#' @param name Name of the GeneratedCohortSet
+#' @description
+#' Adds a new cohort table to the cdm reference with individuals who have drug
+#' exposure records with the specified drug ingredient. Cohort start and end
+#' dates will be based on drug record start and end dates, respectively. Records
+#' that overlap or have fewer days between them than the specified gap era will
+#' be concatenated into a single cohort entry.
+#'
+#' @param cdm A cdm reference.
+#' @param name The name of the new cohort table to add to the cdm reference.
 #' @param ingredient Accepts both vectors and named lists of ingredient names.
 #' For a vector input, e.g., c("acetaminophen", "codeine"), it generates a
 #' cohort table with descendant concept codes for each ingredient, assigning
@@ -27,68 +34,114 @@
 #' each name leads to a combined set of descendant concept codes for the
 #' specified ingredients, creating distinct cohort_definition_id for each
 #' named group.
-#' @param durationRange Range between the duration must be comprised. It should
-#' be a numeric vector of length two, with no NAs and the first value should be
-#' equal or smaller than the second one. It is only required if imputeDuration
-#' = TRUE. If NULL no restrictions are applied.
-#' @param imputeDuration Whether/how the duration should be imputed
-#' "none", "median", "mean", "mode", or it can be a count
-#' @param gapEra Number of days between two continuous exposures to be
-#' considered in the same era.
-#' @param priorUseWashout Prior days without exposure.
-#' @param priorObservation Minimum number of days of prior observation
-#' required for the incident eras to be considered.
-#' @param cohortDateRange Range for cohort_start_date and cohort_end_date
-#' @param limit Choice on how to summarise the exposures. There are
-#' two options:
-#' "all" we summarise the output will be a summary of the exposed eras of
-#' each individual. Each individual can contribute multiple times.
-#' "first" we only consider the first observable era of each individual that fulfills the criteria provided
-#' in previous parameters. In this case each individual can not contribute with multiple rows.
 #' @param doseForm Only descendants codes with the specified dose form
 #' will be returned. If NULL, descendant codes will be returned regardless
 #' of dose form.
+#' @param doseUnit Only descendants codes with the specified dose unit
+#' will be returned. If NULL, descendant codes will be returned regardless
+#' of dose unit
+#' @param routeCategory Only descendants codes with the specified route
+#' will be returned. If NULL, descendant codes will be returned regardless
+#' of route category.
 #' @param ingredientRange Used to restrict descendant codes to those
 #' associated with a specific number of ingredients. Must be a vector of length
 #' two with the first element the minimum number of ingredients allowed and
 #' the second the maximum. A value of c(2, 2) would restrict to only concepts
 #' associated with two ingredients.
-#' @return The function returns the 'cdm' object with the created cohorts as
-#' references of the object.
+#' @param gapEra Number of days between two continuous exposures to be
+#' considered in the same era. Records that have fewer days between them than
+#' this gap will be concatenated into the same cohort record.
+#' @param durationRange Deprecated.
+#' @param imputeDuration Deprecated.
+#' @param priorUseWashout Deprecated
+#' @param priorObservation Deprecated.
+#' @param cohortDateRange Deprecated.
+#' @param limit Deprecated.
+#'
+#' @return The function returns the cdm reference provided with the addition of
+#' the new cohort table.
 #'
 #' @export
 #'
 #' @examples
 #' \donttest{
 #' library(DrugUtilisation)
+#' library(dplyr)
+#'
 #' cdm <- mockDrugUtilisation()
+#'
 #' cdm <- generateIngredientCohortSet(
 #'   cdm = cdm,
 #'   ingredient = "acetaminophen",
-#'   name = "test"
+#'   name = "acetaminophen"
 #' )
-#' cdm
+#'
+#' cdm$acetaminophen |>
+#'   glimpse()
 #' }
 #'
 generateIngredientCohortSet <- function(cdm,
                                         name,
                                         ingredient = NULL,
-                                        durationRange = c(1, Inf),
-                                        imputeDuration = "none",
-                                        gapEra = 0,
-                                        priorUseWashout = 0,
-                                        priorObservation = 0,
-                                        cohortDateRange = as.Date(c(NA, NA)),
-                                        limit = "all",
                                         doseForm = NULL,
-                                        ingredientRange = c(1, Inf)) {
+                                        doseUnit = NULL,
+                                        routeCategory = NULL,
+                                        ingredientRange = c(1, Inf),
+                                        gapEra = 1,
+                                        durationRange = lifecycle::deprecated(),
+                                        imputeDuration = lifecycle::deprecated(),
+                                        priorUseWashout = lifecycle::deprecated(),
+                                        priorObservation = lifecycle::deprecated(),
+                                        cohortDateRange = lifecycle::deprecated(),
+                                        limit = lifecycle::deprecated()) {
+  if (lifecycle::is_present(durationRange)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "generateIngredientCohortSet(durationRange = )"
+    )
+  }
+  if (lifecycle::is_present(imputeDuration)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0", what = "generateIngredientCohortSet(imputeDuration = )"
+    )
+  }
+  if (lifecycle::is_present(priorUseWashout)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "generateIngredientCohortSet(priorUseWashout = )",
+      with = "requirePriorDrugWashout()"
+    )
+  }
+  if (lifecycle::is_present(priorObservation)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "generateIngredientCohortSet(priorObservation = )",
+      with = "requireObservationBeforeDrug()"
+    )
+  }
+  if (lifecycle::is_present(cohortDateRange)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "generateIngredientCohortSet(cohortDateRange = )",
+      with = "requireDrugInDateRange()"
+    )
+  }
+  if (lifecycle::is_present(limit)) {
+    lifecycle::deprecate_warn(
+      when = "0.7.0",
+      what = "generateIngredientCohortSet(limit = )",
+      with = "requireIsFirstDrugEntry()"
+    )
+  }
+
   if (!is.list(ingredient)) {
     conceptSet <- CodelistGenerator::getDrugIngredientCodes(
       cdm = cdm,
       name = ingredient,
       doseForm = doseForm,
       ingredientRange = ingredientRange,
-      withConceptDetails = FALSE
+      doseUnit = doseUnit,
+      routeCategory = routeCategory
     )
   } else {
     conceptSet <- lapply(ingredient, function(values) {
@@ -98,7 +151,8 @@ generateIngredientCohortSet <- function(cdm,
           name = value,
           doseForm = doseForm,
           ingredientRange = ingredientRange,
-          withConceptDetails = FALSE
+          doseUnit = doseUnit,
+          routeCategory = routeCategory
         )
       }) |>
         unname() |>
@@ -111,13 +165,7 @@ generateIngredientCohortSet <- function(cdm,
     cdm = cdm,
     name = name,
     conceptSet = conceptSet,
-    durationRange = durationRange,
-    imputeDuration = imputeDuration,
-    gapEra = gapEra,
-    priorUseWashout = priorUseWashout,
-    priorObservation = priorObservation,
-    cohortDateRange = cohortDateRange,
-    limit = limit
+    gapEra = gapEra
   )
 
   cdm[[name]] <- cdm[[name]] |>
